# Glean JavaScript SDK

The Glean JavaScript SDK is not based on the same [Rust component](../../../dev/core/index.html)
as the other Glean SDKs. Instead it is a full re-implementation of the Glean APIs in JavaScript.

It can be used in:

- **Browser extensions**: available as `@mozilla/glean` [on npm](https://www.npmjs.com/package/@mozilla/glean);
- **Qt/QML applications**: available for download on [glean.js/releases page](https://github.com/mozilla/glean.js/releases).

Support for other JavaScript environments such as websites, Electron apps and Node.js applications
is not out of the question and if you would like to use the SDK in one of these environments
[reach out](../../index.html#contact) to our team.
